@@ -1,12 +1,11 @@
 from typing import *
 import argparse
 import sys
-import pathlib
 
 from strip_markdown import *
 
 def main() -> Optional[int]:
-    parser = argparse.ArgumentParser(description='Converts markdown to plain text')
+    parser = argparse.ArgumentParser(description='Converts markdown file to plain text')
     parser.add_argument('md',  type=str, help='markdown input file')
     parser.add_argument('txt', type=str, help='text output file', nargs='?', default='')
     args = parser.parse_args()
